#[non_exhaustive]pub enum PositionEncoding {
Sinusoidal,
Learned,
RoPE,
ALiBi,
NoPE,
}Expand description
Position-encoding strategies supported by attention layers in this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sinusoidal
Classic sinusoidal position embeddings (Vaswani et al., 2017).
Learned
Learned absolute position embeddings (BERT, GPT-2 style).
RoPE
Rotary Position Embedding — RoPE (Su et al., 2021).
ALiBi
Attention with Linear Biases — ALiBi (Press et al., 2021).
NoPE
No position encoding (NoPE) — relies on relative information in the input or is provided externally.